import { select } from 'd3';
const main = (container) => {
  const width = container.clientWidth;
  const height = container.clientHeight;
  const svg = d3
    .select(container)
    .append('svg')
    .attr('width', width)
    .attr('height', height)
    .style('background', 'lightgreen');
  const defs = svg.append('defs');
  const gradient = defs
    .append('linearGradient')
    .attr('id', 'vaseGradient')
    .attr('x1', '0%')
    .attr('x2', '0%')
    .attr('y1', '100%')
    .attr('y2', '0%');
  gradient
    .append('stop')
    .attr('offset', '0%')
    .attr('stop-color', '#8B4513');
  gradient
    .append('stop')
    .attr('offset', '100%')
    .attr('stop-color', '#CD853F');

  const vaseWidth = 150;
  const vaseHeight = 200;
  const vaseX = width / 2 - vaseWidth / 2;
  const vaseY = height - vaseHeight;

  // Draw the vase using the gradient
  svg
    .append('circle')
    .attr('cx', width / 2)
    .attr('cy', vaseY + vaseHeight - 30)
    .attr('r', vaseWidth / 2)
    .attr('fill', 'url(#vaseGradient)');
  svg
    .append('rect')
    .attr('x', vaseX)
    .attr('y', vaseY)
    .attr('width', vaseWidth)
    .attr('height', vaseHeight - 30)
    .attr('fill', 'url(#vaseGradient)');

  // Data for three flowers
  const flowersData = [1, 2, 3];
  const stemHeight = 100;
  const stemWidth = 10;
  const stemFill = 'green';

  // Drawing stems and flowers
  flowersData.forEach((_, i) => {
    const stemX =
      vaseX +
      (vaseWidth / (flowersData.length + 1)) * (i + 1) -
      stemWidth / 2;
    const flowerCenterY = vaseY - stemHeight;

    svg
      .append('rect')
      .attr('x', stemX)
      .attr('y', flowerCenterY)
      .attr('width', stemWidth)
      .attr('height', stemHeight)
      .attr('fill', stemFill);

    const leafPath = `M${stemX},${flowerCenterY + 30} q10,-20 20,0 q-10,20 -20,0`;
    svg
      .append('path')
      .attr('d', leafPath)
      .attr('fill', 'green');

    const petalColors = ['pink', 'orange', 'yellow'];
    const flowerRadius = 20;

    for (
      let angle = 0;
      angle < 2 * Math.PI;
      angle += Math.PI / 4
    ) {
      const petalX = stemX + flowerRadius * Math.cos(angle);
      const petalY =
        flowerCenterY + flowerRadius * Math.sin(angle);
      svg
        .append('circle')
        .attr('cx', petalX)
        .attr('cy', petalY)
        .attr('r', 10)
        .attr('fill', petalColors[i % petalColors.length]);
    }

    svg
      .append('circle')
      .attr('cx', stemX)
      .attr('cy', flowerCenterY)
      .attr('r', 10)
      .attr('fill', 'black');
  });
};

document.addEventListener('DOMContentLoaded', function () {
  main(document.getElementById('container'));
});
